aboutsummaryrefslogtreecommitdiff
path: root/debian/tests/compile-and-tests.lisp
diff options
context:
space:
mode:
Diffstat (limited to 'debian/tests/compile-and-tests.lisp')
-rw-r--r--debian/tests/compile-and-tests.lisp10
1 files changed, 6 insertions, 4 deletions
diff --git a/debian/tests/compile-and-tests.lisp b/debian/tests/compile-and-tests.lisp
index de3eb6c..57fe51d 100644
--- a/debian/tests/compile-and-tests.lisp
+++ b/debian/tests/compile-and-tests.lisp
@@ -7,9 +7,11 @@
(asdf:*user-cache* (uiop:getenv "AUTOPKGTEST_TMP")))
(asdf:load-system "consfigurator/tests"))
-;; we can't use ASDF:TEST-SYSTEM because its return value does not indicate
-;; whether any tests failed
-(unless (consfigurator/tests::do-tests)
- (uiop:quit 2))
+;; We can't use ASDF:TEST-SYSTEM because its return value does not indicate
+;; whether any tests failed. We have to switch the package back and forth as
+;; CL-USER has no *CONSFIG*.
+(let ((*package* (find-package :consfigurator/tests)))
+ (unless (consfigurator/tests::do-tests)
+ (uiop:quit 2)))
(fresh-line)